@@ -1,9 +1,9 @@
 test.windex <-
 function(dat, tree, traits, focal=dat[,2],SE = TRUE, reps,plot=TRUE,...){
 w<-windex(dat, tree, traits, focal,SE=SE) #calculate Wheatsheaf index
-w.index<-w$"Wheatsheaf Index"
-l.ci<-w$'Lower 95% CI'
-u.ci<-w$'Upper 95% CI'
+w.index<-w$w
+l.ci<-w$low95
+u.ci<-w$up95
 
 t.vec<-c() #set up empty vector for bootstrapped samples
  pb <- txtProgressBar(min = 0, max = reps, style = 3)
@@ -15,7 +15,7 @@ new<- dat[sample(nrow(X),replace=TRUE),-1] #randomly permutate focal and traits
 newdat<-cbind(species=dat$species,new)
 
 w.rep<-windex(newdat, tree, traits, focal) #recalculate Wheatsheaf index for new data
-t.vec[i]<-w.rep$"Wheatsheaf Index"
+t.vec[i]<-w.rep$w
 
 }
 p.val<-length(which(t.vec>=w.index))/reps #calculate p value
@@ -27,9 +27,9 @@ hist(t.vec,xlab='Wheatsheaf Index',main="",xlim=c(min(c(t.vec,l.ci))-leeway,max(
 abline(v=w.index)
 abline(v=l.ci,lty=3)
 abline(v=u.ci,lty=3)
-legend('top',horiz=TRUE,inset=c(0,-0.1),xpd=TRUE,bty = "n",c('Wheatsheaf index','CI'),lty=c(1,3))
+legend('top',horiz=TRUE,inset=c(0,-0.1),xpd=TRUE,bty = "n",c('Observed Wheatsheaf index','CI'),lty=c(1,3))
 
 }
 close(pb)
-return(list("P-value="=p.val))
+return(list("w"=w.index,"low95"=l.ci,"up95"=u.ci,"P"=p.val,"boot.dist"=t.vec))
 }
